@@ -1,4 +1,4 @@
-GLOBE.ORTH<-function(lam0, phi1, R=1, plotmap=TRUE, plotline=TRUE, add=FALSE, map=coastmap, mapcol =grey(.2) , linecol = grey(.7) )
+GLOBE.ORTH<-function(lam0, phi1, R=1, plotmap=TRUE, plotline=TRUE, add=FALSE, map=coastmap, mapcol =grey(.2) , linecol = grey(.7), fill=FALSE )
   {
     ###   use orthogonal projection to plot a global view
     if(missing(R)) R = 1
@@ -79,6 +79,11 @@ GLOBE.ORTH<-function(lam0, phi1, R=1, plotmap=TRUE, plotline=TRUE, add=FALSE, ma
             ##  lines(nx, ny , col='green' )
           }
         lines(x, y , col=mapcol )
+        if(fill==TRUE)
+          {
+            polygon(x,y,col=mapcol )
+
+          }
       }
   }
 
